OrderItemWidget class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- OrderItemWidget
Constructors
- OrderItemWidget({Key? key, required String orderCode, required String finalPrice, required int orderState, required dynamic onTap(), Color arrowIconColor = Colors.blue, Color backgroundColor = Colors.white, Color borderColor = const Color(0xFFE0E0E0), Color textColor = Colors.black, Color priceColor = Colors.blue, double borderRadius = 16.0, EdgeInsetsGeometry padding = const EdgeInsets.all(8.0), EdgeInsetsGeometry margin = const EdgeInsets.only(bottom: 8.0), Widget? trailingWidget})
-
const
- OrderItemWidget.fromOrder({required dynamic order, required dynamic onTap(), Color arrowIconColor = Colors.blue})
-
factory
Properties
- arrowIconColor → Color
-
final
- backgroundColor → Color
-
final
- borderColor → Color
-
final
- borderRadius → double
-
final
- finalPrice → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry
-
final
- onTap → dynamic Function()
-
final
- orderCode → String
-
final
- orderState → int
-
final
- padding → EdgeInsetsGeometry
-
final
- priceColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color
-
final
- trailingWidget → Widget?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getStatusColor(
int state) → Color -
getStatusText(
int state) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited